summaryrefslogtreecommitdiff
path: root/libcxx/test/std/language.support/support.limits/support.limits.general/version.version.compile.pass.cpp
diff options
context:
space:
mode:
authoryronglin <yronglin777@gmail.com>2023-05-18 01:05:13 +0800
committeryronglin <yronglin777@gmail.com>2023-05-18 01:05:25 +0800
commitacce2a315945e386a7be6f014ebe90c2a28f38d9 (patch)
tree4dc99806d34604023905d11f645690782afe0a66 /libcxx/test/std/language.support/support.limits/support.limits.general/version.version.compile.pass.cpp
parent5ae9098e5c1564bdfe0ae0fdbc02e581138eeac7 (diff)
downloadllvm-acce2a315945e386a7be6f014ebe90c2a28f38d9.tar.gz
[libc++] Implement P2505R5(Monadic operations for std::expected).
Implement P2505R5(https://www.open-std.org/jtc1/sc22/wg21/docs/papers/2022/p2505r5.html) Reviewed By: #libc, philnik, ldionne Differential Revision: https://reviews.llvm.org/D140911
Diffstat (limited to 'libcxx/test/std/language.support/support.limits/support.limits.general/version.version.compile.pass.cpp')
-rw-r--r--libcxx/test/std/language.support/support.limits/support.limits.general/version.version.compile.pass.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libcxx/test/std/language.support/support.limits/support.limits.general/version.version.compile.pass.cpp b/libcxx/test/std/language.support/support.limits/support.limits.general/version.version.compile.pass.cpp
index e1bdde4551a7..74073cfcf1c1 100644
--- a/libcxx/test/std/language.support/support.limits/support.limits.general/version.version.compile.pass.cpp
+++ b/libcxx/test/std/language.support/support.limits/support.limits.general/version.version.compile.pass.cpp
@@ -76,7 +76,7 @@
__cpp_lib_exchange_function 201304L [C++14]
__cpp_lib_execution 201603L [C++17]
201902L [C++20]
- __cpp_lib_expected 202202L [C++2b]
+ __cpp_lib_expected 202211L [C++2b]
__cpp_lib_filesystem 201703L [C++17]
__cpp_lib_format 202106L [C++20]
__cpp_lib_format_ranges 202207L [C++2b]
@@ -4161,8 +4161,8 @@
# ifndef __cpp_lib_expected
# error "__cpp_lib_expected should be defined in c++2b"
# endif
# if __cpp_lib_expected != 202202L
# error "__cpp_lib_expected should have the value 202202L in c++2b"
# endif
# if !defined(_LIBCPP_AVAILABILITY_HAS_NO_FILESYSTEM)
@@ -4161,8 +4161,8 @@
# error "__cpp_lib_expected should be defined in c++2b"
# endif
-# if __cpp_lib_expected != 202202L
-# error "__cpp_lib_expected should have the value 202202L in c++2b"
+# if __cpp_lib_expected != 202211L
+# error "__cpp_lib_expected should have the value 202211L in c++2b"
# endif
# if !defined(_LIBCPP_AVAILABILITY_HAS_NO_FILESYSTEM)